@@ -1,4 +1,4 @@
-from whatismyip.providers import providers_dict
+from checkip.providers import providers_dict
 
 
 def get_ip(obtainer):
